pub struct BuiltBlobs {
pub storage: Arc<dyn Storage>,
pub watch_provider: Option<Arc<dyn WatchProvider>>,
pub provision_tier: ProvisionTier,
}Expand description
The blob backend plus, on a cloud object store with notification provisioning
configured, its blob-change WatchProvider
and operator tier (FA-5b2). The provider/tier are consumed only by the handler
runtime, so they are dead code in a --no-default-features (no handlers) build.
Fields
storage: Arc<dyn Storage>watch_provider: Option<Arc<dyn WatchProvider>>provision_tier: ProvisionTierAuto Trait Implementations
impl !RefUnwindSafe for BuiltBlobs
impl !UnwindSafe for BuiltBlobs
impl Freeze for BuiltBlobs
impl Send for BuiltBlobs
impl Sync for BuiltBlobs
impl Unpin for BuiltBlobs
impl UnsafeUnpin for BuiltBlobs